# Logfire LSP

A [Language Server Protocol](https://microsoft.github.io/language-server-protocol/) implementation
for the [Logfire platform](https://logfire.pydantic.dev/docs/).

> [!WARNING]
>
> This project is in early development.

<div align="center">
    <picture>
      <img src="./assets/example.png" alt="LSP Example">
    </picture>
</div>
